'use strict';

describe('Controller: loginController', function () {

    // load the module
    beforeEach(module('dhapTFCCUiApp'));

    var loginController, sqliteMock, scope, registerInstrumentServiceMock, passPromise = true, successResponse, successStatus, failureResponse, serialNumberGeneratorMock;


    beforeEach(function () {
        //todo: use Math.random
        successResponse = {
            serialNumber: 123,
            userName: "abc",
            instrumentToken: "12knqkhw3qh",
            instrumentId: "12121212"
        };

        successStatus = 200;

        failureResponse = "ERROR";

        registerInstrumentServiceMock = {
            registerInstrument: function (data, successCallBackFunction, failureCallBackFunction) {
                if (passPromise) {
                    successCallBackFunction(successResponse, successStatus);
                } else {
                    failureCallBackFunction(failureResponse);
                }
            }
        };

        sqliteMock = {
            initializeDataBase: function () {
            },

            insert: function () {
            }
        }

        serialNumberGeneratorMock = {
            getSerialNumber: function () {
                return "244343453455";
            }
        };

    });


    // Initialize the controller and a mock scope
    beforeEach(inject(function ($controller, $rootScope) {
        scope = $rootScope.$new();
        loginController = $controller('loginController', {
            $scope: scope,
            registerInstrumentService: registerInstrumentServiceMock,
            serialNumberGenerator: serialNumberGeneratorMock,
            Sqlite: sqliteMock
        });
    }));

    it('should call RegisterInstrumentService service', function () {
        scope.validateUser(true);
        expect(scope.successResponse).toBe(successResponse);
        expect(scope.failureResponse).toBe(undefined);
    });

    it('should create submitted variable with default value as false', function() {
      expect(scope.submitted).toBe(false);
    });

    it('submitted variable value should be true once user click on Login button', function() {
        scope.validateUser(true);
        expect(scope.submitted).toBe(true);
    });

    it('check for failure response when call to RegisterInstrumentService', function () {
        passPromise = false;
        scope.validateUser(true);
        expect(scope.failureResponse).toBe(failureResponse);
        expect(scope.successResponse).toBe(undefined);
    });


});