'use strict';

describe('Service: registerInstrumentService', function () {

    // load the module
    beforeEach(module('dhapTFCCUiApp'));

    var registerInstrumentService, $httpBackend, inputData, successResponseValue, successStatus, failureResponseValue;


    // Initialize the service
    beforeEach(inject(function (_registerInstrumentService_, $injector) {
        registerInstrumentService = _registerInstrumentService_;
        $httpBackend = $injector.get('$httpBackend');

    }));

    beforeEach(function () {
        inputData = {
            "serialNumber": "sdkvbdkvbsada32123413",
            "type": "CCU",
            "username": "durga.kumari@lifetech.com",
            "password": "test"
        }
    });

    /* registerInstrument service tests */
    it('Check registerInstrument service Success', function () {
        // var responseDetails = {};
        var registrationDetails = {
            "instrumentId": "61536",
            "instrumentToken": "6C1fro60wsmd+XcexEFwmX+FpbI8xf0IDzsveWYu",
            "instrumentType": "CCU",
            "serialNumber": "sdkvbdkvbsada32123413",
            "userName": "durga.kumari@lifetech.com"

        };

        //Mocking HTTP
        $httpBackend.expectPOST('https://test.apps.thermofisher.com/dhap-tfcc-gateway/svc/api/v1/instrument/register').respond(200, registrationDetails);
        registerInstrumentService.registerInstrument(registrationDetails, function (successResponse, status) {
            successResponseValue = successResponse;
            successStatus = status;
        }, function (failureResponse) {
            failureResponseValue = failureResponse;
        });
        $httpBackend.flush();
        expect(successResponseValue).toEqual(registrationDetails);
        expect(successStatus).toEqual(200);
        expect(failureResponseValue).toEqual(undefined);
    });

    it('Check registerInstrument service failure', function () {
        // var responseDetails = {};
        successResponseValue = undefined;
        var registrationDetails = {
            "instrumentId": "61536",
            "instrumentToken": "6C1fro60wsmd+XcexEFwmX+FpbI8xf0IDzsveWYu",
            "instrumentType": "CCU",
            "serialNumber": "sdkvbdkvbsada32123413",
            "userName": "durga.kumari@lifetech.com"

        };
        var error = {
            errorDescription: "not loaded"
        };

        //Mocking HTTP
        $httpBackend.expectPOST('https://test.apps.thermofisher.com/dhap-tfcc-gateway/svc/api/v1/instrument/register').respond(500, error);
        registerInstrumentService.registerInstrument(registrationDetails, function (successResponse, status) {
            successResponseValue = successResponse;
            successStatus = status;
        }, function (err) {
            failureResponseValue = err;
        });
        $httpBackend.flush();
        expect(successResponseValue).toBeUndefined();
        expect(failureResponseValue.errorDescription).toEqual("not loaded");
    });

});